@@ -7,7 +7,7 @@ use warnings;
 
 =head1 NAME
 
-Biber::Entries
+Biber::Entries - Biber::Entries objects
 
 =head2 new
 
@@ -129,7 +129,7 @@ L<https://github.com/plk/biber/issues>.
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2009-2012 François Charette and Philip Kime, all rights reserved.
-Copyright 2012-2019 Philip Kime, all rights reserved.
+Copyright 2012-2023 Philip Kime, all rights reserved.
 
 This module is free software.  You can redistribute it and/or
 modify it under the terms of the Artistic License 2.0.
